[PHP-DOC] cvs: phpdoc /scripts revcheck.php From: Friedhelm Betz (holliwell <email protected>)
Date: 12/14/02

betz Sat Dec 14 07:57:45 2002 EDT

  Modified files:
    /phpdoc/scripts revcheck.php
  Log:
  sapi_type check because of the different behavior
  of the cli and cgi version
  
  
Index: phpdoc/scripts/revcheck.php
diff -u phpdoc/scripts/revcheck.php:1.32 phpdoc/scripts/revcheck.php:1.33
--- phpdoc/scripts/revcheck.php:1.32 Fri Nov 1 04:52:43 2002
+++ phpdoc/scripts/revcheck.php Sat Dec 14 07:57:45 2002
@@ -88,11 +88,15 @@
     $MAINT = "";
 }
 
-// Main directory of the PHP documentation (one dir up
-// in cvs). We do need the trailing slash!
-$DOCDIR = "../";
+// Main directory of the PHP documentation (depends on the
+// sapi used). We do need the trailing slash!
+$sapi_type = php_sapi_name();
+if ($sapi_type === "cli"){
+ $DOCDIR = "./";
+ }else {
+ $DOCDIR = "../";
+}
 
-
 // =========================================================================
 // Functions to get revision info and credits from a file
 // =========================================================================
@@ -534,11 +538,11 @@
 td,a,p { color:#000000; }
 h2 { font-size:28px; }
 th { font-weight:bold; }
-.blue { background-color:#666699; }
-.act { background-color:#68D888; }
+.blue { background-color:#666699; }
+.act { background-color:#68D888; }
 .norev { background-color:#f4a460; }
 .old { background-color:#eee8aa; }
-.crit { background-color:#ff6347; }
+.crit { background-color:#ff6347; }
 .wip { background-color:#dcdcdc; }
 .r { text-align:right }
 .rb { text-align:right; font-weight:bold; }

-- 
PHP Documentation Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php